<?php
# For security reasons, these lines should either be included from a
# config file above the web directory, or possibly captured during a
# login and stored in the SESSION superglobal array
define('FM_HOST', '127.0.0.1');
define('FM_FILE', 'Product Catalog.fp7');
define('FM_USER', 'esmith');
define('FM_PASS', 'm4rg0t');
#
# this is the include for the API for PHP
require_once ('FileMaker.php');
#
# instantiate a new FileMaker object
$fm = new FileMaker(FM_FILE, FM_HOST, FM_USER, FM_PASS);
#
# grab search criteria, if any has been sent
if (isset($_GET['criteria'])) {
    $criteria = $_GET['criteria'];
} else {
    $criteria = '';
}
#
# grab the sort column, if one has been sent
if (isset($_GET['sort'])) {
    $sort = $_GET['sort'];
} else {
    $sort = '';
}
#
# initialize some variables
$page_content = '';
$this_page = $_SERVER['PHP_SELF'];
#
# set the layout name for this page
$layout_name = 'Product List';
#
# get the layout as an object
$layout = $fm->getLayout($layout_name);
#
# check for errors
if (FileMaker::isError($layout)) {
    die('<p>' . $layout->getMessage() . ' (error ' . $layout->code . ')</p>');
}
#
# get the fields as an array of objects
$fields = $layout->getFields();
#
# did the user send any search criteria?
if ($criteria == '') {
    # the user has not performed a search, so create a find all command
    $request = $fm->newFindAllCommand($layout_name);
} else {
    # create a new search transaction
    $request = $fm->newFindCommand($layout_name);
    #
    # indicate that we want an OR search so ANY matching fields will return a result
    $request->setLogicalOperator(FILEMAKER_FIND_OR);
    #
    # NOTE: I am using the getResult method of the field object to check
    # the data type of the field. Even in a find request, data type
    # formatting must be respected. If we didn't check for this, we
    # would get an error if we searched a date field for the value
    # 'Erica', for example
    foreach($fields as $field) {
        # get name of the current field
        $field_name = $field->getName();
        #
        # get data type of the current field
        $field_data_type = $field->getResult();
        #
        # format the criteria appropriately for the current field data type
        if ($field_data_type == 'date') {
            if (strtotime($criteria)) {
                $request->addFindCriterion($field_name, date('n/j/Y', strtotime($criteria)));
            }
        } elseif ($field_data_type == 'time') {
            if (strtotime($criteria)) {
                $request->addFindCriterion($field_name, date('H:i:s', strtotime($criteria)));
            }
        } elseif ($field_data_type == 'timestamp') {
            if (strtotime($criteria)) {
                $request->addFindCriterion($field_name, date('n/j/Y H:i:s', strtotime($criteria)));
            }
        } elseif ($field_data_type == 'container') {
            # skip this field because it is a container (like a blob) and can't be searched for text
            
        } else {
            $request->addFindCriterion($field_name, $criteria);
        }
    }
}
#
# specify sort column (aka, field), if any
if ($sort != '') {
    $request->addSortRule($sort, 1);
}
#
# execute the search transaction
$result = $request->execute();
#
# check for errors (including no records found)
if (FileMaker::isError($result)) {
    die('<p>' . $result->getMessage() . ' (error ' . $result->code . ')</p>');
}
#
# display the found count
$total = $result->getTableRecordCount();
$found = $result->getFoundSetCount();
if ($criteria == '') {
    $page_content.= '<p>Displaying ' . $found . ' record(s) of ' . $total . ' total</p>' . PHP_EOL;
} else {
    $page_content.= '<p>Your search for "' . $criteria . '" returned ' . $found . ' record(s) of ' . $total . ' total</p>' . PHP_EOL;
}
#
# get the result record set as an array of record objects
$records = $result->getRecords();
#
# start compiling our record output
$page_content.= '<table border="1">' . PHP_EOL;
$page_content.= '<tr>';
$page_content.= '<th>&nbsp;</th>';
#
# loop through array of field objects to draw header
foreach($fields as $field) {
    $field_name = $field->getName();
    # include the criteria and sort in the header links
    $page_content.= '<th><a href="' . $this_page . '?criteria=' . $criteria . '&sort=' . $field_name . '">' . $field_name . '</a></th>';
}
$page_content.= '</tr>' . PHP_EOL;
#
# loop through record objects
foreach($records as $record) {
    $page_content.= '<tr>';
    $page_content.= '<td><a href="product.php?recid=' . $record->getRecordId() . '">View</a></td>';
    #
    # loop through array of field objects
    foreach($fields as $field) {
        $field_name = $field->getName();
        $field_data_type = $field->getResult();
        if ($field_data_type == 'container') {
            $field_val = '<img src="get_image.php?path=' . urlencode($record->getField($field_name)) . '" />';
        } else {
            $field_val = $record->getField($field_name);
            $field_val = nl2br($field_val);
        }
        $page_content.= '<td>' . $field_val . '</td>';
    }
    $page_content.= '</tr>' . PHP_EOL;
}
$page_content.= '</table>' . PHP_EOL;
?>
<html>
    <head>
        <title>Product List</title>
    </head>
    <body>
        <form action="<?php echo $this_page ?>" method="get">
            <input type="text" name="criteria" value="<?php echo $criteria; ?>">
            <input type="submit" value="search">
        </form>
<!-- BEGIN DYNAMIC OUTPUT -->        
<?php echo $page_content; ?>
<!-- END DYNAMIC OUTPUT -->        
    </body>
</html>
